## Annotation of Identified Variants

Annotation of Identified Variants to Create Reports for Clinicians to Assist Therapeutic Decisions

## Prerequisites

It requires three main modules: pandas, myvariant and reportlab

```
pip3 install pandas
pip3 install myvariant
pip3 install reportlab
```

## Installing

```
pip3 install aiv
```
